pitchtools.ObjectVector
=======================

.. inheritance-diagram:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.clear

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.copy

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.get

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.has_key

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.items

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.iteritems

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.iterkeys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.itervalues

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.keys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.pop

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.popitem

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.setdefault

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.update

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.values

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.viewitems

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.viewkeys

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.viewvalues

    Inherited from :py:class:`__builtin__.dict`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__cmp__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__contains__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__delitem__

    Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__eq__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__ge__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__getitem__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__gt__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__iter__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__le__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__len__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__lt__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__ne__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__repr__

    Inherited from :py:class:`__builtin__.dict`

.. automethod:: abjad.tools.pitchtools.ObjectVector.ObjectVector.ObjectVector.__setitem__

    Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`
